Stan Math Library: stan/math/prim/mat/fun/crossprod.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

crossprod.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_CROSSPROD_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_CROSSPROD_HPP
3
4 #include <stan/math/prim/mat/fun/typedefs.hpp>
5 #include <stan/math/prim/mat/fun/tcrossprod.hpp>
6
7 namespace stan {
8 namespace math {
9
16 inline matrix_d
17 crossprod(const matrix_d& M) {
18 return tcrossprod(static_cast<matrix_d>(M.transpose()));
19 }
20
21 }
22 }
23 #endif
tcrossprod.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::tcrossprod
Eigen::Matrix< fvar< T >, R, R > tcrossprod(const Eigen::Matrix< fvar< T >, R, C > &m)
Definition: tcrossprod.hpp:17
stan::math::crossprod
Eigen::Matrix< fvar< T >, C, C > crossprod(const Eigen::Matrix< fvar< T >, R, C > &m)
Definition: crossprod.hpp:17
stan::math::matrix_d
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic > matrix_d
Type for matrix of double values.
Definition: typedefs.hpp:23
typedefs.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.